# PeakEvo

An application to acquire data from a spectrometer (supports OceanView hardware
via the seabreeze module) and track the position of a peak over time.

## Install

### Installation with uv

1. Install uv (follow the [official installation instructions](https://docs.astral.sh/uv/getting-started/installation/))
2. download the peakevo zip from [this link](https://gitlab.com/c-p/peakevo/-/archive/master/peakevo-master.zip?ref_type=heads)
3. Run: 
   ```
   uv tool install -p3.9 --with pyqt5 --with "seabreeze[pyseabreeze]" -U peakevo-master.zip
   ```

### Manual installation:

This assumes that you have the following requirements fullfilled:

- Python (v3.5 to 3.9)
- qtpy (+ PyQt5 **or** PyQt4 **or** PySide)
- PyQtGraph
- python-seabreeze (tested with pyseabreeze backend)
- peakevo source code in the current directory

Then, do:
```
python setup.py install
```

## Launch

```
peakevo
```
